@@ -236,7 +236,7 @@ SCS = Instruction(
         [
             Argument('x', BYTE),
             Argument('y', BYTE),
-            Argument('charstart', BYTE),
+            Argument('charstart', PTR),
         ]
     )
 
